<?php
namespace CUS\Util;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class Util {
	
    protected $crudService;
    protected $newCode;
    protected $environment;
    protected $dataSourceManager;
    protected $connection;
    
    const TABLE_LISTA = "LISTA";

	public function __construct($crudService, $newCode, $environment, $dataSourceManager, $connection) {
        $this->crudService = $crudService;
        $this->newCode = $newCode;
        $this->environment = $environment;
		$this->dataSourceManager = $dataSourceManager;
		$this->connection = $connection;
	}

    public function validateDuplicatedRecords($row, $dataSourceName, $columns) {
        $conditions = array();
        foreach ($columns as $column) {
            array_push($conditions, array(
                "columnName" => $column,
                "operator"   => '=',
                "value"      => $row[$column]
            ));
        }
        $dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions);

        if (!empty($dataSet->getRows())) {
            throw new \Exception("registerExists", 1);
        }
    }

    public function insertLista($cdlistaArray) {
        $dataSourceName = strtolower(self::TABLE_LISTA);
        $nrlista = $this->newCode->getCodeByTableName(self::TABLE_LISTA, $this->environment->getNrOrg());
        $sql = "INSERT INTO " . self::TABLE_LISTA . " (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        
        foreach ($cdlistaArray as $cdlista) {
            $params = array(
                "NRLISTA" => $nrlista,
                "CDLISTA" => $cdlista
            );
            $query = $this->connection->prepare($sql);
    	    $query->execute($params);
        }
        
        return $nrlista;
    }
    
    public function deleteLista($nrlista) {
        $dataSourceName = strtolower(self::TABLE_LISTA);
        $conditions = array(
            array(
                "columnName" => "NRLISTA",
                "operator"   => '=',
                "value"      => $nrlista
            )
        );
        $dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions);
        $this->dataSourceManager->delete($dataSet);
    }

    public function deleteConsplanWithFilial($nrconsplan, $cdfilicpla) {
        $sql = "DELETE FROM CONSPLAN WHERE NRCONSPLAN = :NRCONSPLAN AND (CDFILICPLA = :CDFILICPLA OR :CDFILICPLA = NULL) AND NRORG = :NRORG";
        $params = array(
            "NRCONSPLAN" => $nrconsplan,
            "CDFILICPLA" => $cdfilicpla,
            "NRORG"      => $this->environment->getNrOrg()
        );
        $query = $this->connection->prepare($sql);
    	$query->execute($params);
    }
    
    public function deleteConsplan($nrconsplan, $cdfilicpla = NULL) {
        $sql = "DELETE FROM CONSPLAN WHERE NRCONSPLAN = :NRCONSPLAN AND NRORG = :NRORG";
        $params = array(
            "NRCONSPLAN" => $nrconsplan,
            "NRORG"      => $this->environment->getNrOrg()
        );
        $query = $this->connection->prepare($sql);
    	$query->execute($params);
    }
}